==> org.eclipse.osee.server.p2-0.26.0-SNAPSHOT.zip: org/eclipse/osee/ats/api/workdef/AtsWorkDefinitionTokens.java <==
/*******************************************************************************
 * Copyright (c) 2019 Boeing.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Boeing - initial API and implementation
 *******************************************************************************/
package org.eclipse.osee.ats.api.workdef;

/**
 * @author Donald G. Dunne
 */
public class AtsWorkDefinitionTokens {

   // @formatter:off
   public static AtsWorkDefinitionToken WorkDef_Goal = new AtsWorkDefinitionToken(142177L, "WorkDef_Goal");

   public static AtsWorkDefinitionToken WorkDef_Review_Decision = new AtsWorkDefinitionToken(25335L, "WorkDef_Review_Decision");
   public static AtsWorkDefinitionToken WorkDef_Review_PeerToPeer = new AtsWorkDefinitionToken(25334L, "WorkDef_Review_PeerToPeer");

   public static AtsWorkDefinitionToken WorkDef_Sprint = new AtsWorkDefinitionToken(6915497L, "WorkDef_Sprint");

   public static AtsWorkDefinitionToken WorkDef_Task_Default = new AtsWorkDefinitionToken(105373L, "WorkDef_Task_Default");
   public static AtsWorkDefinitionToken WorkDef_Task_AtsConfig2Example = new AtsWorkDefinitionToken(824992064L, "WorkDef_Task_AtsConfig2Example");

   public static AtsWorkDefinitionToken WorkDef_Team_Simple = new AtsWorkDefinitionToken(72302L, "WorkDef_Team_Simple");
   public static AtsWorkDefinitionToken WorkDef_Team_Default = new AtsWorkDefinitionToken(72301L, "WorkDef_Team_Default");

   public static AtsWorkDefinitionToken WorkDef_Team_AtsConfig2Example = new AtsWorkDefinitionToken(282846363L, "WorkDef_Team_AtsConfig2Example");
   // @formatter:on

}

==> org.eclipse.osee.server.p2-1.0.0-SNAPSHOT.zip: org/eclipse/osee/ats/api/workdef/AtsWorkDefinitionTokens.java <==
/*********************************************************************
 * Copyright (c) 2019 Boeing
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Boeing - initial API and implementation
 **********************************************************************/

package org.eclipse.osee.ats.api.workdef;

/**
 * @author Donald G. Dunne
 */
public class AtsWorkDefinitionTokens {

   // @formatter:off
   public static AtsWorkDefinitionToken WorkDef_Goal = new AtsWorkDefinitionToken(142177L, "WorkDef_Goal");

   public static AtsWorkDefinitionToken WorkDef_Review_Decision = new AtsWorkDefinitionToken(25335L, "WorkDef_Review_Decision");
   public static AtsWorkDefinitionToken WorkDef_Review_PeerToPeer = new AtsWorkDefinitionToken(25334L, "WorkDef_Review_PeerToPeer");
   public static AtsWorkDefinitionToken WorkDef_Review_PeerToPeer_Demo = new AtsWorkDefinitionToken(3324222L, "WorkDef_Review_PeerToPeer_Demo");

   public static AtsWorkDefinitionToken WorkDef_Sprint = new AtsWorkDefinitionToken(6915497L, "WorkDef_Sprint");

   public static AtsWorkDefinitionToken WorkDef_Task_Default = new AtsWorkDefinitionToken(105373L, "WorkDef_Task_Default");
   public static AtsWorkDefinitionToken WorkDef_Task_AtsConfig2Example = new AtsWorkDefinitionToken(824992064L, "WorkDef_Task_AtsConfig2Example");

   public static AtsWorkDefinitionToken WorkDef_Team_Simple = new AtsWorkDefinitionToken(72302L, "WorkDef_Team_Simple");
   public static AtsWorkDefinitionToken WorkDef_Team_Default = new AtsWorkDefinitionToken(72301L, "WorkDef_Team_Default");

   public static AtsWorkDefinitionToken WorkDef_Team_AtsConfig2Example = new AtsWorkDefinitionToken(282846363L, "WorkDef_Team_AtsConfig2Example");
   public static AtsWorkDefinitionToken WorkDef_Team_Simple_InWork = new AtsWorkDefinitionToken(7285608L, "WorkDef_Team_Simple_InWork");
   public static AtsWorkDefinitionToken WorkDef_Team_ProductLine = new AtsWorkDefinitionToken(10837868L, "WorkDef_Team_ProductLine");

   // @formatter:on

}
